// Copyright 2010-2020, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// Libraries for transliterations.

#include "transliteration/transliteration.h"

namespace mozc {
namespace transliteration {

// static
bool T13n::IsInFullAsciiTypes(TransliterationType type) {
  return (type == FULL_ASCII || type == FULL_ASCII_UPPER ||
          type == FULL_ASCII_LOWER || type == FULL_ASCII_CAPITALIZED);
}

// static
bool T13n::IsInHalfAsciiTypes(TransliterationType type) {
  return (type == HALF_ASCII || type == HALF_ASCII_UPPER ||
          type == HALF_ASCII_LOWER || type == HALF_ASCII_CAPITALIZED);
}

// static
bool T13n::IsInHiraganaTypes(TransliterationType type) {
  return (type == HIRAGANA);
}

// static
bool T13n::IsInFullKatakanaTypes(TransliterationType type) {
  return (type == FULL_KATAKANA);
}

// static
bool T13n::IsInHalfKatakanaTypes(TransliterationType type) {
  return (type == HALF_KATAKANA);
}

// static
TransliterationType T13n::ToggleFullAsciiTypes(
    const TransliterationType current_type) {
  return ((current_type == FULL_ASCII)
              ? FULL_ASCII_UPPER
              : (current_type == FULL_ASCII_UPPER)
                    ? FULL_ASCII_LOWER
                    : (current_type == FULL_ASCII_LOWER)
                          ? FULL_ASCII_CAPITALIZED
                          : FULL_ASCII);
}

// static
TransliterationType T13n::ToggleHalfAsciiTypes(
    const TransliterationType current_type) {
  return ((current_type == HALF_ASCII)
              ? HALF_ASCII_UPPER
              : (current_type == HALF_ASCII_UPPER)
                    ? HALF_ASCII_LOWER
                    : (current_type == HALF_ASCII_LOWER)
                          ? HALF_ASCII_CAPITALIZED
                          : HALF_ASCII);
}

}  // namespace transliteration
}  // namespace mozc
